==> najva-android-sdk-1.2.14-sources.jar: com/najva/sdk/core/utils/StaticFields.java <==
package com.najva.sdk.core.utils;

public class StaticFields {
    public static final String BLANK = "";
    public static final String NOTIFICATION_JSON = "json";

    public static final String API_KEY = "api_key";
    public static final String TOKEN = "token_id";
    public static final String WEBSITE_ID = "website_id";
    public static final String LATITUDE = "latitude";
    public static final String LONGITUDE = "longitude";
    public static final String ALTITUDE = "altitude";
    public static final String ACCURACY = "accuracy";
    public static final String APP_VERSION = "app_version";
    public static final String NAJVA_TOKEN = "najvaـtoken";
    public static final String UPDATE_TIME = "update_time";
    public static final String GET_TOKEN = "get_token";
    public static final String WEBSITE = "website";
    public static final String SIMCARD_NAME = "sim_operator_name";
    public static final String DEVICE_MODEL = "device_model";
    public static final String ANDROID_VERSION = "android_version";
    public static final String ANDROID_ID = "android_id";
    public static final String ANDROID_PACKAGE_INFO = "android_package_info";
    public static final String MANUFACTURER = "manufacturer";
    public static final String NOTIFICATION_ID = "notification_id";
    public static final String SIM_CARD_OPERATOR = "operator";
    public static final String PACKAGE_NAME = "package_name";
    public static final String APP_LABEL = "app_label";
    public static final String BUTTON_ID = "button_id";
    public static final String COOKIE = "Cookie";
    public static final String NAJVA_SDK_VERSION = "najva_sdk_version";
    public static final String OPERATION = "operation";
    public static final String OPERATION_ADD = "add";
    public static final String OPERATION_REMOVE = "remove";

    public static final String JSON_DATA = "json-data";

    public static final String URL = "url";
    public static final String ONCLICK_ACTION = "onclick_action";
    public static final String NOTIFICATION_CONTENT = "notification_content";
    public static final String PRIORITY = "priority";

    public static final String TITLE = "title";
    public static final String BODY = "body";
    public static final String LIGHT_UP_SCREEN = "light_up_screen";

    public static final String BTN1_ENABLED = "btn1_enabled";
    public static final String BTN1_TITLE = "btn1_title";
    public static final String BTN1_ICON = "btn1_icon";
    public static final String BTN1_ID = "btn1_id";
    public static final String BTN1_ACTION = "btn1_action";
    public static final String BTN1_ADDRESS = "btn1_final_address";
    public static final String BTN1_CONTENT = "btn1_content";

    public static final String BTN2_ENABLED = "btn2_enabled";
    public static final String BTN2_TITLE = "btn2_title";
    public static final String BTN2_ICON = "btn2_icon";
    public static final String BTN2_ID = "btn2_id";
    public static final String BTN2_ACTION = "btn2_action";
    public static final String BTN2_ADDRESS = "btn2_final_address";
    public static final String BTN2_CONTENT = "btn2_content";

    public static final String ICON = "icon";
    public static final String IMAGE = "image";

    public static final String MESSAGE_ID = "message_id";
    public static final String FINAL_ADDRESS = "complete_url";
    public static final String WEBSITE_INFO = "website_info";
    public static final String CLICK_TYPE = "click_type";

    public static final String NOTIFICATION_PRIORITY_HIGH = "High";
    public static final String NOTIFICATION_PRIORITY_LOW = "Low";

    public static final String BUTTON_ACTION_CLOSE = "close";
    public static final String DATA_CONFIG = "config";

    public static final String SDK_ACTION = "sdk_action";
    public static final String SDK_ACTION_TYPE = "sdk_action_type";
    public static final String INTERVAL_ACTION = "location_interval";
    public static final String ACTIVE_USER = "active_user";


    public static final String NOTIFICATION_TAG = "najva_tag";
    public static final String REMOTE_CONFIG = "remote_config";
    public static final String BUTTONS = "buttons";
    public static final String CONTENT = "content";
    public static final String ICON_NUMBER = "icon_number";
    public static final String ID = "id";

    public static final String NAJVA = "najva";

    public static final String METHOD = "method";
    public static final String NAME = "name";
    public static final String POST = "post";
    public static final String HEADER = "header";
    public static final String RESPONSE = "response";

    public static final long REPEAT_INTERVAL = 12 * 60L;
    public static final String LOCATION_UNIQUE_WORK = "locationWorker";
    public static final String NOTIFICATION_TYPE = "notification-type";
    public static final String ACTION_NOTIFICATION_REMOVED = "com.najva.sdk.receiver.NOTIFICATION_DELETED";
    public static final String PUBLIC_PREFS = "najva_public_prefs";
    public static final String LOGGER_PREFS = "najva_logger";
    public static final String IN_APP_MESSAGING = "in-app-message";
    public static final String ANDROID = "Android";
    public static final String CHANNEL_ID_HIGH_PRIORITY = "Najva_high_priority";
    public static final String CHANNEL_ID_LOW_PRIORITY = "Najva_low_priority";
    public static final String CHANNEL_DESCRIPTION_HIGH = "High Priority";
    public static final String CHANNEL_DESCRIPTION_LOW = "Low Priority";

    public static final String EVENT_TYPE_JSON = "json-data";
    public static final String EVENT_TYPE_TOKEN = "najva-token";
    public static final String EVENT_NOTIFICATION_RECEIVER = "notification-receiver";
    public static final String EVENT_CLICK = "notification-click";
    public static final String EVENT_TYPE_INAPP = "inapp-message";
    public static final String ACTION = "action";
    public static final String SUMMARY = "summary";
    public static final String CHANNEL = "channel";
    public static final String NOTIFICATION_REPORT_ID = "notification_report_id";
    public static final String UTM = "utm";
    public static final String UUID = "uuid";
}

==> najva-android-sdk-1.3.1-sources.jar: com/najva/sdk/core/utils/StaticFields.java <==
package com.najva.sdk.core.utils;

public class StaticFields {
    public static final String BLANK = "";
    public static final String NOTIFICATION_JSON = "json";

    public static final String API_KEY = "api_key";
    public static final String TOKEN = "token_id";
    public static final String WEBSITE_ID = "website_id";
    public static final String LATITUDE = "latitude";
    public static final String LONGITUDE = "longitude";
    public static final String ALTITUDE = "altitude";
    public static final String ACCURACY = "accuracy";
    public static final String APP_VERSION = "app_version";
    public static final String NAJVA_TOKEN = "najvaـtoken";
    public static final String UPDATE_TIME = "update_time";
    public static final String GET_TOKEN = "get_token";
    public static final String WEBSITE = "website";
    public static final String SIMCARD_NAME = "sim_operator_name";
    public static final String DEVICE_MODEL = "device_model";
    public static final String ANDROID_VERSION = "android_version";
    public static final String ANDROID_ID = "android_id";
    public static final String MANUFACTURER = "manufacturer";
    public static final String NOTIFICATION_ID = "notification_id";
    public static final String PACKAGE_NAME = "package_name";
    public static final String APP_LABEL = "app_label";
    public static final String BUTTON_ID = "button_id";
    public static final String COOKIE = "Cookie";
    public static final String NAJVA_SDK_VERSION = "najva-sdk-version";

    public static final String JSON_DATA = "json-data";

    public static final String URL = "url";
    public static final String ONCLICK_ACTION = "onclick_action";
    public static final String NOTIFICATION_CONTENT = "notification_content";
    public static final String PRIORITY = "priority";

    public static final String TITLE = "title";
    public static final String BODY = "body";
    public static final String LIGHT_UP_SCREEN = "light_up_screen";

    public static final String ICON = "icon";
    public static final String IMAGE = "image";

    public static final String MESSAGE_ID = "message_id";
    public static final String FINAL_ADDRESS = "complete_url";

    public static final String NOTIFICATION_PRIORITY_HIGH = "High";
    public static final String NOTIFICATION_PRIORITY_LOW = "Low";

    public static final String NOTIFICATION_TAG = "najva_tag";
    public static final String BUTTONS = "buttons";
    public static final String CONTENT = "content";
    public static final String ICON_NUMBER = "icon_number";
    public static final String ID = "id";

    public static final String NAJVA = "najva";

    public static final String METHOD = "method";
    public static final String NAME = "name";
    public static final String POST = "post";
    public static final String HEADER = "header";

    public static final long REPEAT_INTERVAL = 12 * 60L;
    public static final String LOCATION_UNIQUE_WORK = "locationWorker";
    public static final String NOTIFICATION_TYPE = "notification-type";
    public static final String PUBLIC_PREFS = "najva_public_prefs";
    public static final String CHANNEL_ID_HIGH_PRIORITY = "Najva_high_priority";
    public static final String CHANNEL_ID_LOW_PRIORITY = "Najva_low_priority";
    public static final String CHANNEL_DESCRIPTION_HIGH = "High Priority";
    public static final String CHANNEL_DESCRIPTION_LOW = "Low Priority";

    public static final String EVENT_TYPE_TOKEN = "najva-token";
    public static final String EVENT_NOTIFICATION_RECEIVER = "notification-receiver";
    public static final String EVENT_CLICK = "notification-click";
    public static final String ACTION = "action";
    public static final String SUMMARY = "summary";
    public static final String UUID = "uuid";
}
